<?php

namespace App\Http\Controllers;

use App\Models\Product;
use App\Models\Campaign;
use Illuminate\Http\Request;

class ProductController extends Controller
{

    public function productsDetails($productId)
    {
        // Get product details with brand and images
        $productDetails = Product::where('id', $productId)
            ->with('brand', 'images')
            ->with(['similarProducts' => function ($query) use ($productId) {
                $currentProduct = Product::find($productId);
                if ($currentProduct) {
                    $query->where('category_id', $currentProduct->category_id)
                        ->where('id', '!=', $productId);
                }
            }])
            ->first();

        // Check if product details exist
        if (!$productDetails) {
            return response()->json(['success' => false, 'message' => 'Product not found', 'data' => []]);
        }

        // Fetch the campaign named 'Most Popular'
        $campaign = Campaign::where('name', 'Most Popular')->first();

        if ($campaign) {
            // Retrieve products associated with this campaign, excluding the current product
            $mostPopularProducts = Product::with('brand', 'images')
                ->where('id', '!=', $productId) // Exclude the current product
                ->whereHas('category', function ($query) use ($campaign) {
                    $query->whereHas('campaignContexts', function ($subQuery) use ($campaign) {
                        $subQuery->where('campaign_id', $campaign->id);
                    });
                })
                ->get();

            // Add most popular products to the product details
            $productDetails['most_popular'] = $mostPopularProducts;
        } else {
            $productDetails['most_popular'] = [];
        }

        return response()->json([
            'success' => true,
            'message' => 'Product details',
            'data' => $productDetails
        ]);
    }

    // public function productsDetails($productId)
    // {

    //     $productDetails = Product::where('id', $productId)
    //         ->with('brand', 'images')
    //         ->with(['similarProducts' => function ($query) use ($productId) {
    //             $currentProduct = Product::find($productId);
    //             if ($currentProduct) {
    //                 $query->where('category_id', $currentProduct->category_id)
    //                     ->where('id', '!=', $productId);
    //             }
    //         }])
    //         ->first();


    //     $campaign = Campaign::where('name', 'Most Popular')->first();

    //     if ($campaign && $productDetails) {
    //         // Now retrieve products associated with this campaign
    //         $products = Product::with('brand', 'images')->whereHas('category', function ($query) use ($campaign) {
    //             $query->whereHas('campaignContexts', function ($subQuery) use ($campaign) {
    //                 $subQuery->where('campaign_id', $campaign->id);
    //             });
    //         })->get();
    //         $productDetails['most_popular'] = $products;
    //     }


    //     return response()->json(['success' => true, 'message' => 'product details', 'data' => $productDetails]);
    // }



    public function searchProducts(Request $request)
    {
        $searchProduct = Product::with('brand', 'images')
            ->where('name', 'LIKE', '%' . $request->name . '%')->paginate(10);

        if (!$searchProduct) {
            return response()->json(
                ['success' => false, 'message' => 'no products found', 'data' => []]
            );
        }

        return response()->json([
            'success' => true,
            'message' => 'search details ',
            'data' => $searchProduct
        ]);
    }
}
